/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.admin.rest.dto.v1_0.util;

import com.liferay.list.type.model.ListTypeEntry;
import com.liferay.list.type.service.ListTypeEntryLocalServiceUtil;
import com.liferay.object.admin.rest.dto.v1_0.ObjectStateFlow;
import com.liferay.object.admin.rest.dto.v1_0.ObjectStateTransition;
import com.liferay.object.model.ObjectState;
import com.liferay.object.service.ObjectStateLocalServiceUtil;
import com.liferay.petra.function.transform.TransformUtil;
import com.liferay.portal.kernel.exception.PortalException;

/**
 * @author Feliphe Marinho
 */
public class ObjectStateFlowUtil {

	public static ObjectStateFlow toObjectStateFlow(
		com.liferay.object.model.ObjectStateFlow objectStateFlow) {

		return new ObjectStateFlow() {
			{
				id = objectStateFlow.getObjectStateFlowId();
				objectStates = TransformUtil.transformToArray(
					ObjectStateLocalServiceUtil.getObjectStateFlowObjectStates(
						objectStateFlow.getObjectStateFlowId()),
					ObjectStateFlowUtil::_toObjectState,
					com.liferay.object.admin.rest.dto.v1_0.ObjectState.class);
			}
		};
	}

	private static com.liferay.object.admin.rest.dto.v1_0.ObjectState
			_toObjectState(ObjectState objectState)
		throws PortalException {

		ListTypeEntry listTypeEntry =
			ListTypeEntryLocalServiceUtil.getListTypeEntry(
				objectState.getListTypeEntryId());

		return new com.liferay.object.admin.rest.dto.v1_0.ObjectState() {
			{
				id = objectState.getObjectStateId();
				key = listTypeEntry.getKey();
				objectStateTransitions = TransformUtil.transformToArray(
					ObjectStateLocalServiceUtil.getNextObjectStates(
						objectState.getObjectStateId()),
					ObjectStateFlowUtil::_toObjectStateTransition,
					ObjectStateTransition.class);
			}
		};
	}

	private static ObjectStateTransition _toObjectStateTransition(
			ObjectState objectState)
		throws PortalException {

		ListTypeEntry listTypeEntry =
			ListTypeEntryLocalServiceUtil.getListTypeEntry(
				objectState.getListTypeEntryId());

		return new ObjectStateTransition() {
			{
				key = listTypeEntry.getKey();
			}
		};
	}

}